==> qtjambi-uic-6.3.5-sources.jar: io/qt/uic/ui4/DomDate.java <==
package io.qt.uic.ui4;


/**
 * <p>Java wrapper for Qt class DomDate</p>
 */
public class DomDate extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomDate(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomDate instance);
    
    @io.qt.QtUninvokable
    public final void clearElementDay(){
        clearElementDay_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementDay_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementMonth(){
        clearElementMonth_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementMonth_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementYear(){
        clearElementYear_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementYear_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementDay(){
        return elementDay_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementDay_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementMonth(){
        return elementMonth_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementMonth_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementYear(){
        return elementYear_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementYear_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementDay(){
        return hasElementDay_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementDay_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementMonth(){
        return hasElementMonth_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementMonth_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementYear(){
        return hasElementYear_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementYear_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void read(io.qt.core.QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @io.qt.QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @io.qt.QtUninvokable
    public final void setElementDay(int a){
        setElementDay_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementDay_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setElementMonth(int a){
        setElementMonth_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementMonth_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setElementYear(int a){
        setElementYear_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementYear_native_int(long __this__nativeId, int a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer, java.lang.String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @io.qt.QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected DomDate(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-uic-6.5.2-sources.jar: io/qt/uic/ui4/DomDate.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>DomDate</code></p>
 */
public class DomDate extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomDate::<wbr>DomDate()</code></p>
     */
    public DomDate(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomDate instance);
    
    /**
     * <p>See <code>DomDate::<wbr>clearElementDay()</code></p>
     */
    @QtUninvokable
    public final void clearElementDay(){
        clearElementDay_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementDay_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomDate::<wbr>clearElementMonth()</code></p>
     */
    @QtUninvokable
    public final void clearElementMonth(){
        clearElementMonth_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementMonth_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomDate::<wbr>clearElementYear()</code></p>
     */
    @QtUninvokable
    public final void clearElementYear(){
        clearElementYear_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementYear_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomDate::<wbr>elementDay()const</code></p>
     */
    @QtUninvokable
    public final int elementDay(){
        return elementDay_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int elementDay_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomDate::<wbr>elementMonth()const</code></p>
     */
    @QtUninvokable
    public final int elementMonth(){
        return elementMonth_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int elementMonth_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomDate::<wbr>elementYear()const</code></p>
     */
    @QtUninvokable
    public final int elementYear(){
        return elementYear_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int elementYear_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomDate::<wbr>hasElementDay()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementDay(){
        return hasElementDay_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementDay_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomDate::<wbr>hasElementMonth()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementMonth(){
        return hasElementMonth_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementMonth_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomDate::<wbr>hasElementYear()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementYear(){
        return hasElementYear_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementYear_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomDate::<wbr>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomDate::<wbr>setElementDay(int)</code></p>
     */
    @QtUninvokable
    public final void setElementDay(int a){
        setElementDay_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementDay_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomDate::<wbr>setElementMonth(int)</code></p>
     */
    @QtUninvokable
    public final void setElementMonth(int a){
        setElementMonth_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementMonth_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomDate::<wbr>setElementYear(int)</code></p>
     */
    @QtUninvokable
    public final void setElementYear(int a){
        setElementYear_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementYear_native_int(long __this__nativeId, int a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    /**
     * <p>See <code>DomDate::<wbr>write(QXmlStreamWriter&amp;,<wbr>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomDate(QPrivateConstructor p) { super(p); } 
    
}
